package Ex6;

our $VERSION = 0.01;

1;

=pod

=head1 EXAMPLE

 use strict;
 use warnings;

 # Arguments.
 my $arg1 = $ARGV[0] || '';
 my $arg2 = $ARGV[1] || '';

 # Print argument.
 print 'Argument #0: '.$arg1."\n";
 print 'Argument #1: '.$arg2."\n";

=cut
